==> amarok_2.9.0.orig.tar.xz: amarok-2.9.0/src/playlistgenerator/Constraint.h <==
/****************************************************************************************
 * Copyright (c) 2008-2011 Soren Harward <stharward@gmail.com>                          *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#ifndef APG_CONSTRAINT
#define APG_CONSTRAINT

#include "ConstraintNode.h"

#include <QObject>

/* ABC for all Constraints */
class Constraint : public ConstraintNode {
    Q_OBJECT
    public:
        virtual int getNodeType() const { return ConstraintNode::ConstraintType; }

    protected:
        Constraint( ConstraintNode* );
};

#endif

==> amarok-3.1.81.tar.xz: amarok-3.1.81/src/playlistgenerator/Constraint.h <==
/****************************************************************************************
 * Copyright (c) 2008-2011 Soren Harward <stharward@gmail.com>                          *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#ifndef APG_CONSTRAINT
#define APG_CONSTRAINT

#include "ConstraintNode.h"

#include <QObject>

/* ABC for all Constraints */
class Constraint : public ConstraintNode {
    Q_OBJECT
    public:
        int getNodeType() const override { return ConstraintNode::ConstraintType; }

    protected:
        Constraint( ConstraintNode* );
};

#endif
